@@ -13,21 +13,14 @@ package Dist::Zilla::PluginBundle::Author::Celogeek;
 use strict;
 use warnings;
 
-our $VERSION = '0.5';    # VERSION
+our $VERSION = '0.6';    # VERSION
 
 use Moose;
 use Class::MOP;
 with 'Dist::Zilla::Role::PluginBundle::Easy',
     'Dist::Zilla::Role::PluginBundle::PluginRemover';
 
-sub before_build {
-    my $self = shift;
-    unless ( -d 'xt' ) {
-        mkdir('xt');
-    }
-    unless ( -e 'xt/perltidy.rc' ) {
-        if ( open my $f, '>', 'xt/perltidy.rc' ) {
-            print $f <<EOF
+my $PERLTIDY_SAMPLE = <<'EOF'
 #Perl Best Practice Conf
 -l=78
 -i=4
@@ -44,22 +37,33 @@ sub before_build {
 -nolq
 -wbb="% + - * / x != == >= <= =~  !~ < > | & >= < = **= += *= &= <<= &&= -= /= |= >>= ||= .= %= ^= x="
 EOF
-                ;
+    ;
+my $PERLCRITIC_SAMPLE = <<'EOF'
+severity        = 3
+verbose         = 6
+top             = 50
+theme           = pbp || core || bugs || security || maintenance
+criticism-fatal = 1
+color           = 1
+allow-unsafe    = 1
+EOF
+    ;
+
+sub before_build {
+    my $self = shift;
+    unless ( -d 'xt' ) {
+        mkdir('xt');
+    }
+    unless ( -e 'xt/perltidy.rc' ) {
+        if ( open my $f, '>', 'xt/perltidy.rc' ) {
+            print $f $PERLTIDY_SAMPLE;
             close $f;
         }
     }
     unless ( -e 'xt/perlcritic.rc' ) {
         if ( open my $f, '>', 'xt/perlcritic.rc' ) {
-            print $f <<EOF
-severity = 3
-theme = (pbp || security) && bugs
-criticism-fatal = 1
-color = 1
-
-[Subroutines::ProtectPrivateSubs]
-allow = Encode::_utf8_on
-EOF
-                ;
+            print $f $PERLCRITIC_SAMPLE;
+            close $f;
         }
     }
     return;
@@ -118,7 +122,7 @@ Dist::Zilla::PluginBundle::Author::Celogeek - Dist::Zilla like Celogeek
 
 =head1 VERSION
 
-version 0.5
+version 0.6
 
 =head1 OVERVIEW
 
